[LTP] [PATCH v2 3/4] set_mempolicy01: make use of tst_set_timeout

Li Wang liwang@redhat.com
Thu Jan 9 05:55:31 CET 2025


Signed-off-by: Li Wang <liwang@redhat.com>
---
 testcases/kernel/syscalls/set_mempolicy/set_mempolicy01.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/testcases/kernel/syscalls/set_mempolicy/set_mempolicy01.c b/testcases/kernel/syscalls/set_mempolicy/set_mempolicy01.c
index cd39c6c41..39e7156d0 100644
--- a/testcases/kernel/syscalls/set_mempolicy/set_mempolicy01.c
+++ b/testcases/kernel/syscalls/set_mempolicy/set_mempolicy01.c
@@ -41,9 +41,9 @@ static void setup(void)
 	 * has multiple NUMA nodes, the test matrix combination grows exponentially
 	 * and bring about test time to increase extremely fast.
 	 *
 	 * Here reset the maximum runtime according to the NUMA nodes.
 	 */
-	tst_set_runtime(test.runtime * (1 << nodes->cnt/16));
+	tst_set_timeout(test.timeout * (1 << nodes->cnt/16));
 }
 
 static void cleanup(void)
@@ -119,7 +119,7 @@ static struct tst_test test = {
 	.tcnt = 2,
 	.forks_child = 1,
 	.needs_checkpoints = 1,
-	.runtime = 600,
+	.timeout = 600,
 };
 
 #else
@@ -41,9 +41,9 @@ static void setup(void)
 	 * and bring about test time to increase extremely fast.
 	 *
-	 * Here reset the maximum runtime according to the NUMA nodes.
+	 * Here reset the entire timeout according to the NUMA nodes.
 	 */
-- 
2.47.1



More information about the ltp mailing list